class Menu(object):

    def __init__(self, days, valid_from, valid_to, allergens_legend):
        self.days = days
        self.valid_from = valid_from
        self.valid_to = valid_to
        self.allergens_legend = allergens_legend

